;---------------------------------------------------------
;---------------------------------------------------------
;---------------------------------------------------------
;------------------B A N K      T H R E E-----------------
;---------------------------------------------------------
;---------------------------------------------------------
;---------------------------------------------------------


    org $3000
    rorg $F000

Start3
    sta $1FF6

;---------------------------------------------------------
;---------------------------------------------------------
;---------------------------------------------------------
DeathRoutine
    lda #BETWEENLEVELSDELAY
    sta BetweenLevelCounter
    lda GameFlags
    and #<~(SCROLLPF_BIT|PLAYERCONTROL_BIT|MOVESANTA_BIT|ANIMATESANTA_BIT)
    ora #BETWEENLEVELS_BIT
    sta GameFlags
    rts
;---------------------------------------------------------

CheckDeathConditionsSubroutine

;---Check for death conditions!
;   condition 1: at left edge of screen (ProtX == 1) EDIT: and touching playfield!
;   condition 2: timer at zero  - now checking this during VSYNC (when timer is updated).
    lda SantaTemp           ;CXP0FB stored in here
    bpl NotDeadOffScreen
    ldy ProtX
    cpy #1
    bne NotDeadOffScreen
    jmp DeathRoutine

NotDeadOffScreen
    lda EnergyExtraLives
    and #$F0
    bne NotDeadOutOfEnergy
    jmp DeathRoutine

NotDeadOutOfEnergy
    rts

;---------------------------------------------------------

PFCollisionSubroutine
    lda SantaTemp           ;CXP0FB stored in here
    bpl NoPFCollision

    ;--hit PF: stop PF scrolling, take away player control, set forced action counter
    ;--special case: if Santa is higher than...83, then he has hit the masking playfield.
    ; in that case, just increment ProtX and continue as normal.
    lda ProtY
    cmp #84
    bcc NormalPFCollision
    inc ProtX
    rts
NormalPFCollision
    lda GameFlags
    and #<~(SCROLLPF_BIT|PLAYERCONTROL_BIT)  ;--stop scrolling and take away control from player
    sta GameFlags
    lda #HITPFFORCEDACTION
    sta ForcedActionCounter
NoPFCollision
    rts

;---------------------------------------------------------

ItemCollisionSubroutine

;---Check for collisions with Items
    lda CXPPMM
    bmi HitAnItemDoSomething
;   jmp NoItemCollision
    rts
HitAnItemDoSomething
ItemCollisionActions
    ;--we hit an item, so check ProtY to figure which one (can't have hit both!)
    lda #50
    cmp ProtY
    bcs FloorItemCollision
    ;--hit sky item
    lda ItemFlags
    and #$F0
    lsr
    lsr
    lsr
    tay
    lda SkyItemJumpTable,Y
    sta Temp
    lda SkyItemJumpTable+1,Y
    sta Temp+1
    jmp (Temp)

FloorItemCollision
    lda ItemFlags
    and #$0F
    asl
    tay
    lda FloorItemJumpTable,Y
    sta Temp
    lda FloorItemJumpTable+1,Y
    sta Temp+1
    jmp (Temp)




    ;--now, what item is it?

CompressedSpringCollisionRoutine
    inc ItemFlags   ;change bottom two bits from 01 to 10
    lda #INITRAMPINDEX  ;set jump index
    sta JumpIndex
    inc ProtY
    rts


    rts

RightArrowCollisionRoutine
    ;the scrolling speed (by decreasing ScrollSpeed).
    lda ScrollSpeedCounter
    and #%00001100
    sec
    sbc #4          ;Scroll speed stored in bits 2 and 3
    bmi EraseFloorItem  ;if negative, then already scrolling as fast as possible.
    sta Temp
    lda ScrollSpeedCounter
    and #%11110011      ;clear old scroll speed
    ora Temp        ;and set new scroll speed
    sta ScrollSpeedCounter
    jmp EraseFloorItem

EraseFloorItem
    lda ItemFlags
    and #$F0
    sta ItemFlags
    rts

LeftArrowCollisionRoutine
    lda ScrollSpeedCounter
    and #%00001100
    cmp #12
    beq EraseFloorItem  ;already scrolling as slow as possible
    lda ScrollSpeedCounter
    clc
    adc #4          ;scroll speed is in bits 2-3, so adding 4 increments it by one.
    sta ScrollSpeedCounter  ;set new scroll speed
    bne EraseFloorItem  ;branch always, cuz scroll speed will never be zero at this point.

CookiesCollisionRoutine
    ;--cookies action: small points bonus and energy bonus
    jsr FloorItemBonusRoutine
    jmp EraseFloorItem

FloorItemBonusRoutine
    lda ItemFlags
    and #$0F
    tax
ItemBonusRoutine
    dex     ;further adjust index since can't collide with item zero.
    sed
    lda ScoreAdder+1
    clc
    adc ScoreBonusTen,X
    sta ScoreAdder+1
    lda ScoreAdder
    adc ScoreBonusHundred,X
    sta ScoreAdder
    cld
    lda EnergyExtraLives
    clc
    adc EnergyBonus,X
    bcc NoAdjustAfterEnergyBonus
    lda EnergyExtraLives
    ora #$F0
NoAdjustAfterEnergyBonus
    sta EnergyExtraLives
    rts





GiftCollisionRoutine
    jsr FloorItemBonusRoutine
    jmp EraseFloorItem

LurkingSnowmanCollisionRoutine
    ;--lurking snowman action: changes to lunging snowman
    inc ItemFlags
    lda EnergyExtraLives
    and #$0F
    beq CantStealWhatIsntThere
    dec EnergyExtraLives
CantStealWhatIsntThere

    ;--also turn on sound effect.
LungingSnowmanCollisionRoutine
ExpandedSpringCollisionRoutine  ;these collisions don't do anything so they are borrowing this rts.
NoItemCollision
    rts

ToysackCollisionRoutine
CandleCollisionRoutine
CandyCaneCollisionRoutine
BellCollisionRoutine
FinishCoalCollisionRoutine
CocoaCollisionRoutine
MilkCollisionRoutine
    jsr FloorItemBonusRoutine
    jmp EraseFloorItem

CoalCollisionRoutine
    lda EnergyExtraLives
    and #$F0
    beq NoEnergyLossFromCoal
    sec
    sbc #$10
    sta Temp
    lda EnergyExtraLives
    and #$0F
    ora Temp
    sta EnergyExtraLives
NoEnergyLossFromCoal
    jmp FinishCoalCollisionRoutine

EvilBirdCollisionRoutine
SnowspeederCollisionRoutine
    dec ProtX
    rts
ReindeerCollisionRoutine
    lda Level
    asl
    tax
    sed
    lda ScoreAdder+1
    clc
    adc ReindeerBonusTable,X
    sta ScoreAdder+1
    lda ScoreAdder
    adc ReindeerBonusTable+1,X
    sta ScoreAdder
    cld


    lda NewDataCounter  ;number of reindeer stored in top two bits
;   and #$C0
    clc
    adc #$40
;   sta Temp
;   lda NewDataCounter
;   and #$3F
;   ora Temp
    sta NewDataCounter
;   lda Temp
    asl
;   cmp #$80
    bcc DontHaveEnoughReindeerYet
    ;--beat the level stuff:
    lda GameFlags
    and #<~(SCROLLPF_BIT|PLAYERCONTROL_BIT|ANIMATESANTA_BIT|ANIMATEOTHER_BIT|MOVESANTA_BIT)
    ora #BETWEENLEVELS_BIT
    sta GameFlags
    lda #BETWEENLEVELSDELAY
    sta BetweenLevelCounter
    ;--point bonuses for beating the level:
    ;--25 points for each light bulb still lit up (energy) + 100 for each santa hat (extra life)
;    lda EnergyExtraLives
;    and #$0F
;    tax
;    sed
;ExtraLifeBonusLoop
;    lda ScoreAdder
;    clc
;    adc #$01
;    sta ScoreAdder
;    dex
;    bne ExtraLifeBonusLoop

    lda EnergyExtraLives
    lsr
    lsr
    lsr
    lsr
    tax
	beq NoEnergyBonusAtLevelEnd	;in theory this branch should never be taken, 
					;but just to be sure...
	sed
EnergyBonusLoop
    lda ScoreAdder+1
    clc
    adc #$50
    sta ScoreAdder+1
    lda ScoreAdder
    adc #0
    sta ScoreAdder
    dex
    bne EnergyBonusLoop
	cld
NoEnergyBonusAtLevelEnd

DontHaveEnoughReindeerYet
;   jmp EraseSkyItem

EraseSkyItem
    lda ItemFlags
    and #$0F
    sta ItemFlags
    lda #152
    sta SkyItemX
    lda #80
    sta SkyItemY
    rts



ToxicCloudCollisionRoutine
    lda EnergyExtraLives
    sec
    sbc #$10
    bcc NoChangeToEnergyFromToxicCloud  ;this branch should never be followed, I think, but just in case
    sta EnergyExtraLives
NoChangeToEnergyFromToxicCloud
    jmp EraseSkyItem



FlyingHatCollisionRoutine
    ;--gain extra life!
	;	edit!  but only if flying hat bit is not set!
	lda NewDataCounter
	and #HAT_BIT
	bne AlreadyCollectedThisHat
	lda NewDataCounter
	ora #HAT_BIT
	sta NewDataCounter
    lda EnergyExtraLives
    and #$0F
    cmp #$06
    beq AlreadyAtMaximumExtraLivesGetPointsOnly
    inc EnergyExtraLives
AlreadyAtMaximumExtraLivesGetPointsOnly
AlreadyCollectedThisHat
    jsr SkyItemBonusRoutine
    jmp EraseSkyItem

SkyItemBonusRoutine
    lda ItemFlags
    lsr
    lsr
    lsr
    lsr
    clc
    adc #15
    tax
    jmp ItemBonusRoutine

ListCollisionRoutine
    jsr SkyItemBonusRoutine
    jmp EraseSkyItem

LightningCollisionRoutine
SnowFlurryCollisionRoutine
TornadoCollisionRoutine
    lda ProtX
    cmp #80
    lda ForcedActionCounter
    bcc SendSantaFlyingRight
    ora #$80
    .byte $2C
SendSantaFlyingRight
    and #$7F
    sta ForcedActionCounter

    and #$7F
    clc
    adc #10
    cmp #48
    bcc ForcedActionCounterNotTooHigh
    lda #47
ForcedActionCounterNotTooHigh
    sta Temp
    lda ForcedActionCounter
    and #$80
    ora Temp
    sta ForcedActionCounter
    rts


ElfCollisionRoutine
    jsr SkyItemBonusRoutine
    jmp EraseSkyItem

SnowflakeCollisionRoutine
    jsr SkyItemBonusRoutine
    jmp EraseSkyItem
SleighCollisionRoutine
    ;--add points bonus and switch out sky item


    jsr SkyItemBonusRoutine
    lda ItemFlags
    and #$0F
    ora #EVILBIRD
    sta ItemFlags
    rts


;---------------------------------------------------------

ForcedActionSubroutine
    lda ForcedActionCounter
    asl         ;get direction bit into carry
    beq NoForcedAction
    bcc ForceSantaRight
    ;--else force him left
    ;--first check to the left for PF pixel
    lda ProtX
    and #3
    beq CheckLeftPixel

    lda ForcedActionCounter
    and #$7F
    cmp #3
    bcc NoLeftwardCheckForForcedAction
    cmp #8
    bcs FurthestLeftCheck
    lda ProtX
    and #3
    cmp #2
    bcs NoLeftwardCheckForForcedAction
    bcc CheckLeftPixel          ;branch always
FurthestLeftCheck
    lda ProtX
    and #3
    cmp #3
    beq NoLeftwardCheckForForcedAction
CheckLeftPixel
    jsr CheckPFPixelsToLeftOfSantaSubroutine
    and #$FF
    bne NoForcedMoveLeft
NoLeftwardCheckForForcedAction
    lda ForcedActionCounter
    and #$7F
    tax
    lda ProtX
    sec
    sbc ForcedActionTable,X
    bcc NoForcedMoveLeft
    cmp #0
    beq NoForcedMoveLeft
    ;--here we make sure not to ram Santa into the hidden masking PF in the upper left corner of the screen:
    sta Temp        ;save this
    lda ProtY
    cmp #85
    bcc GoAheadAndForceSantaLeft
    lda Temp
    cmp #9
    bcc NoForcedMoveLeft
GoAheadAndForceSantaLeft
    lda Temp
    sta ProtX
NoForcedMoveLeft
    lda ForcedActionCounter
    and #$7F
    tax
    jmp UpdateForcedActionCounter

ForceSantaRight
    lsr
    tax
    lda ProtX
    clc
    adc ForcedActionTable,X
    cmp #144
    bcs NoFurtherRight
    sta ProtX
NoFurtherRight
UpdateForcedActionCounter
    dex
    bne ForcedActionIsntYetOver
    lda GameFlags
    ora PLAYERCONTROL_BIT|SCROLLPF_BIT
    sta GameFlags
ForcedActionIsntYetOver
    txa
    sta Temp
    lda ForcedActionCounter
    and #$80
    ora Temp
    sta ForcedActionCounter
    rts

NoForcedAction

    rts

;---------------------------------------------------------

;---------------------------------------------------------

PlayerControlSubroutine


    ;---can't move further left than pixel 16.  Can't move further right than pixel 144.

    lda #144
    cmp ProtX
    beq NoMoveRight




    ;---check R
    bit SWCHA
    bmi NoMoveRight     ;bit 7 of SWCHA in sign
    inc ProtX
    lda #159
    cmp ProtX
    bcs DoneMovingProtX
    lda #0
    beq SetProtX        ;branch always
NoMoveRight
    lda #16
    cmp ProtX
    bcs NoMoveLeft
    ;--check L
    bit SWCHA
    bvs NoMoveLeft      ;bit 6 of SWCHA in overflow
    ;--here check if a PF block is to the left - if so, do not allow leftward movement!

    lda ProtX
    and #3          ;is Santa on playfield boundary?
    bne GoAheadAndMoveLeft
    jsr CheckPFPixelsToLeftOfSantaSubroutine
    and #$FF
    bne NoMoveLeft
GoAheadAndMoveLeft
    dec ProtX
    bne DoneMovingProtX ;if not zero, then we're done.
    lda #160        ;if zero, then reset to #160
    bne SetProtX        ;branch always
SetProtX
    sta ProtX
NoMoveLeft
DoneMovingProtX

    ;--now - can we jump?  If a floor is beneath his feet, it will be stored in bit one of Temp+10
    ;   and if there is a roof above it will be stored in bit two

    lda Temp+10
    lsr
    bcc NoJumpForYou

    lsr
    bcs NoJumpForYou

    bit INPT4
    bmi NoJumpForYou

    inc ProtY       ;move him up one.

    lda #INITJUMPINDEX
    sta JumpIndex

NoJumpForYou
    rts

;---------------------------------------------------------

MoveSantaVerticallySubroutine

    lda #0
    sta Temp+10     ;clear this variable

    ;--first, find if there is a floor beneath or a roof overhead the player

    ;--find if there is a floor beneath

    lda #P0HEIGHT-1
    cmp ProtY       ;on the floor?
    bne NotOnTheFloor
    lda #1
    bne OnTheFloor      ;branch always
NotOnTheFloor
    ldx #8
FindPossibleFloor
    clc
    adc BandHeightData-1,X
    cmp ProtY
    beq FoundPossibleFloor
    dex
    bne FindPossibleFloor
    lda #0
    beq NoFloorBeneath

FoundPossibleFloor
    jsr FindFloorPixel  ;X holds band number (1-10) that player is possibly standing on.
                ;returns 1 in A if PF floor beneath player, 0 if not.
NoFloorBeneath
OnTheFloor
    sta Temp+10

    ;--now findif there is a roof overhead

    ldy #2
FindPossibleRoofLoopOuter
    lda HeadClearanceTable-1,Y
    ldx #7
FindPossibleRoofLoopInner
    clc
    adc BandHeightData,X
    cmp ProtY
    beq FoundPossibleRoof
    dex
    bne FindPossibleRoofLoopInner
    dey
    bne FindPossibleRoofLoopOuter
    lda #0
    beq NoRoofOverhead
FoundPossibleRoof
    jsr FindFloorPixel  ;X holds band number (0-9) that player is possibly underneath.
                ;returns 1 if PF floor over player, 0 if not.
NoRoofOverhead
    asl
    ora Temp+10
    sta Temp+10


    ;--now, apply knowledge!

    ;--first, if jump index is $FF, then if no floor freefall, else stand

    lda JumpIndex
    cmp #$FF
    beq PossibleFreefall

    ;--if jump index is $FE, then if no floor set jump index to slow freefall, else stand

    cmp #$FE
    beq PossibleBeginFall

    ;--else, in mid jump.   if floor beneath, set jump index to $FE
    ;           if roof overhead and no floor beneath, set jump index to $FF
    lda Temp+10
    and #3
    beq NoFloorAndNoRoof
    and #1
    beq RoofOverheadButNoFloor
    lda #$FE
    .byte $2C
RoofOverheadButNoFloor
    lda #$FF
    sta JumpIndex
PossibleFreefall
    ;--if a floor underneath, then we don't fall, we just stand == exit routine
    lda Temp+10
    and #1
    beq Freefall
    lda #$FE
    sta JumpIndex
    rts

PossibleBeginFall
    lda Temp+10
    and #1
    beq BeginFall
    rts

BeginFall
    lda #BEGINFALLINDEX
    sta JumpIndex
    rts

NoFloorAndNoRoof
    ldx JumpIndex
    cpx #255
    beq Freefall
    lda ProtY
    clc
    adc JumpTable,X
    sta ProtY
    dec JumpIndex
    .byte $2C
Freefall
    dec ProtY


    rts

;---------------------------------------------------------

CheckPFPixelsToLeftOfSantaSubroutine
    lda ProtY
    sec
    sbc #P0HEIGHT-1
    bne FindBottomBand
    ldx #7
    bne FoundBottomBand ;branch always
FindBottomBand
    sta Temp
    ldx #7
FindBottomBandLoop
    lda CumulativeBandHeightTable,X
    cmp Temp
    bcs FoundBottomBand
    dex
    bpl FindBottomBandLoop
    jmp AboveAllBands
FoundBottomBand
    stx Temp+6

    ldx #0
FindTopBandLoop
    lda ProtY
    cmp CumulativeBandHeightTable,X
    bcs FoundTopBand
    inx
    cpx #8
    bne FindTopBandLoop
    ldx #0
FoundTopBand

    ;--here X holds number of highest band that player could bump into.
    lda ProtX
    lsr
    lsr
    sec
    sbc #1
    bcc LeftOfAllBands
    tay     ;Y holds PF block number directly to left of Prot
        ;X holds top band number
    stx Temp+7
    inc Temp+6

FindLeftPFPixelLoop
    ldx Temp+7
    lda PF0Data,X
    sta Temp
    lda PF1Data,X
    sta Temp+1
    lda PF2Data,X
    sta Temp+2
    lda PF3Data,X
    sta Temp+3
    lda PF4Data,X
    sta Temp+4
    lda PF5Data,X
    sta Temp+5

    ldx IndexIntoPFTable,Y
    lda Temp,X
    and SpecificPFPixelsTable,Y
    bne IsWallToTheLeft

    inc Temp+7
    lda Temp+6
    cmp Temp+7
    bne FindLeftPFPixelLoop
    jmp NoWallToTheLeft ;branch always


IsWallToTheLeft
    lda #1
    .byte $2C
LeftOfAllBands
AboveAllBands
NoWallToTheLeft
    lda #0
    rts

;---------------------------------------------------------


;BAND0HEIGHT    =   5   ;height of bands in scanlines
;BAND1HEIGHT    =   10
;BAND2HEIGHT    =   12
;BAND3HEIGHT    =   4
;BAND4HEIGHT    =   4
;BAND5HEIGHT    =   4
;BAND6HEIGHT    =   12
;BAND7HEIGHT    =   10

ScoreBonusHundred
    .byte 0,0,0,0,$07,$01,0,0,$15,$02,$00,$00,$02,$01,$00       ;floor items
    .byte 0,0,0,0,0,0,0,$05,0,$12,0,$22,$03,$25,$50     ;sky items


;---------------------------------------------------------

Overscan    ;for some of the following instructions to work,
        ;X needs to be zero when we get here.
    sta WSYNC
    ldy #2
    sty WSYNC
    sty VBLANK      ;       Turn off screen


    lda  #OVERSCANTIME
    sta  TIM64T

;	jsr ReadConsoleSwitchesInBank2


    lda GameFlags
    and #KERNELTYPE_BITS
    cmp #GAMEKERNEL
    bne SkipOverscanGameLogic

    lda GameFlags
    and #BETWEENLEVELS_BIT
    bne DoNotCheckDeathConditionsBetweenLevels
    jsr CheckDeathConditionsSubroutine
DoNotCheckDeathConditionsBetweenLevels






    lda GameFlags
    and #BETWEENLEVELS_BIT
    bne NoForcedActionWhenBetweenLevels
    jsr ItemCollisionSubroutine
    jsr PFCollisionSubroutine
    jsr ForcedActionSubroutine
NoForcedActionWhenBetweenLevels

    lda GameFlags
    and #BETWEENLEVELS_BIT
    beq NotBetweenLevelsNoLevelSwitch
    jsr BetweenLevelSubroutine
NotBetweenLevelsNoLevelSwitch

    lda GameFlags
    and #MOVESANTA_BIT
    beq DoNotMoveSanta
    ;--no vertical movement when hitting playfield!
    lda SantaTemp       ;collision to playfield stored here
    bmi DoNotMoveSanta
    jsr MoveSantaVerticallySubroutine
DoNotMoveSanta
    ;--here, if there is a floor underneath, the number of reindeer is < 2, and player isn't dead,
    ;   and NOT between levels
    ;   and forced action counter = 0, then start scrolling and give player control
    lda GameFlags
    and #BETWEENLEVELS_BIT
    bne BetweenLevelsDoNotRestartScrolling
    lda Temp+10
    and #1
    beq NoFloorUnderneathDoNotStartScrolling
    lda NewDataCounter  ;number of reindeer stored in top two bits
    and #NUMREINDEER_BITS
    cmp #$80

    beq LevelIsOverDoNotStartScrolling
    lda ForcedActionCounter
    asl
    bne ForcedActionUnderwayDoNotChangeGameFlags
    lda GameFlags
    ora #SCROLLPF_BIT|PLAYERCONTROL_BIT
    sta GameFlags
LevelIsOverDoNotStartScrolling
NoFloorUnderneathDoNotStartScrolling
ForcedActionUnderwayDoNotChangeGameFlags
BetweenLevelsDoNotRestartScrolling

    lda GameFlags
    and #PLAYERCONTROL_BIT
    beq SkipPlayerControl
    jsr PlayerControlSubroutine
SkipPlayerControl

SkipOverscanGameLogic

    jsr MusicSubroutine

    ;--if song pointers are pointing at SilentNightPreFunk then switch to TitleScreen
    lda SongPtr
    cmp #<SilentNightPreFunk
    bne SongNotDone
    lda SongPtr+1
    cmp #>SilentNightPreFunk
    bne SongNotDone
    ;--else, song done:
    lda GameFlags
    and #<~KERNELTYPE_BITS
    ora #TITLESCREEN
    sta GameFlags
    lda #<[JingleBells-2]
    sta SongPtr
    lda #>[JingleBells-2]
    sta SongPtr+1
    lda #0
    sta TempoCounter
    sta NoteLengthC0
	sta Level		;so santa looks right
SongNotDone
NotGameOverScreen

    lda GameFlags
    and #KERNELTYPE_BITS
    cmp #TITLESCREEN
    bne NotOnTitleScreenNoSpecialSantaSetup
    lda #P0HEIGHT-1
    sta ProtY

    lda #REINDEER1
    sta ItemFlags

    lda #18
    sta SkyItemY

    lda GameFlags
    ora #ANIMATESANTA_BIT|ANIMATEOTHER_BIT
    sta GameFlags

;	lda #0
;	sta Level

    lda SkyItemAnimation
    and #$0F
    ora #$30
    sta SkyItemAnimation    ;set max number of reindeer frames
NotOnTitleScreenNoSpecialSantaSetup


    jmp SwitchToBank1FromBank3


;-----------------------------------------------------------

BetweenLevelSubroutine
    lda ScoreAdder
    bne WaitSomeMoreBetweenLevels
    lda ScoreAdder+1
    bne WaitSomeMoreBetweenLevels

    lda Counter
    and #7
    bne DoneWithBetweenLevelSubroutine
    dec BetweenLevelCounter
    beq StartNextLevel
    ldx BetweenLevelCounter
    lda GlobalVolumeTable,X
    sta GlobalVolume
    rts

WaitSomeMoreBetweenLevels
    rts

DoneWithBetweenLevelSubroutine
    rts

StartNextLevel
    lda #0
    sta GlobalVolume
    lda NewDataCounter  ;number of reindeer stored in top two bits

    asl			

    bcc RestartCurrentLevel
    ;--else start next level
;   .byte $2C
	ror		;restore NewDataCounter in Accumulator
	and #<~HAT_BIT	;clear hat bit when advancing a level only!
	sta NewDataCounter
	;--new: score bonus for beating level (level times 2000)

    inc Level

	sed
	lda EnergyExtraLives
	and #$0F
	tax
	beq NoExtraLifeBonus
ExtraLifeBonusLoop
	lda Score+1
	clc
	adc #$10
	sta Score+1
	lda Score
	adc #0
	sta Score
	dex
	bne ExtraLifeBonusLoop
NoExtraLifeBonus
	ldx #2
LevelBonusLoop
	lda Level
	asl
	asl
	asl
	asl
	clc
	adc Score+1
	sta Score+1
	lda Score
	adc #0
	sta Score
	dex
	bne LevelBonusLoop
	cld
	

    lda Level
    cmp #4
    beq YouBeatTheGame
    pla
    pla
    jmp StartNewLevelFromBank3

YouBeatTheGame
    jsr HighScoreSubroutine
    dec Level
    lda GameFlags
    and #<~KERNELTYPE_BITS
    ora #FINALSCREEN
    sta GameFlags
    lda #<[WeWishYou-2]
    sta SongPtr
    lda #>[WeWishYou-2]
    sta SongPtr+1
    lda #0
    sta NoteLengthC0
    sta TempoCounter
    sta GlobalVolume
    rts

RestartCurrentLevel
    lda EnergyExtraLives
    and #$0F
    bne GameNotOver
    ;--game over, man.
    ;   What we eventually want to do here is:
    ;       Check if the score is the new high score - if so, update the high score
    lda GameFlags
    and #<~KERNELTYPE_BITS
    ora #GAMEOVERSCREEN
    sta GameFlags
    lda #0
    sta JumpIndex
    sta ForcedActionCounter
    sta TempoCounter
    sta NoteLengthC0
    ;--reset song pointer here and clear tempo counter
    lda #<[SilentNight-2]
    sta SongPtr
    lda #>[SilentNight-2]
    sta SongPtr+1
    ;--new high score?
    jsr HighScoreSubroutine

    rts

HighScoreSubroutine
	lda HighScore
	cmp Score
	bcc NewHighScore
	bne NoNewHighScore
	lda HighScore+1
	cmp Score+1
	bcc NewHighScore
	bne NoNewHighScore
	lda HighScore+2
	cmp Score+2
	bcs NoNewHighScore
NewHighScore
    lda Score
    sta HighScore
    lda Score+1
    sta HighScore+1
    lda Score+2
    sta HighScore+2
NoNewHighScore
    rts

GameNotOver
    lda #0
    sta JumpIndex
    sta ForcedActionCounter
    sta TempoCounter
    sta NoteLengthC0

    pla
    pla
    dec EnergyExtraLives
    jmp StartNewLevelFromBank3


;---------------------------------------------------------

HorizonKernelSubroutine

    lda #0
    sta WSYNC
    sta VBLANK      ;+3  3  turn off Vertical Blank




Screen1
    sta WSYNC       ;(+3    16)
    ldx Level
    lda HighSkyObjectColorTable,X   ;get HSO color
    sta COLUP1
    lda SkyColorTable,X     ;get sky color
    sta COLUBK
    lda MidSkyObjectColorTable,X    ;get MSO color
    sta COLUP0
    lda #0
    sta NUSIZ0
    sta WSYNC
  IF TV_MODE = PAL
    sta WSYNC
    sta WSYNC
    sta WSYNC
    sta WSYNC
  ENDIF

    ldy #21         ;+2     for displaying sprites :)
;---Second section of screen: 8 scanlines of sun/moon/etc. (P1) and tall scrolling bkgrnd (P0)
    ldx #9      ;+2 14
Screen2
    sta WSYNC
    lda (MidSkyDataPtr),Y
    and MSOMask
    sta GRP0        ;+11    11
    lda (HighSkyDataPtr),Y
    sta GRP1        ;+8 19
    dey
    dex        			 ;+4 23
    bne Screen2     		;+2 25
	

    lda (MidSkyDataPtr),Y   	;+5 30
    and MSOMask         	;+3 33
    dey             		;+2 35
    jsr Ret3
    jsr Ret3			;+24	59
	SLEEP 9			;+6	65
    sec             	;+2 67
;	jmp ContinuedHorizonKernel	;+3	70
;	align 256
;ContinuedHorizonKernel

    sta HMCLR           ;+3 73
    sta GRP0            ;+3 76
    lda LSOX            ;+3  3
DivideLoop1
    sbc #15
    bcs DivideLoop1     ;+4/5    7/12.../59

    eor #7          ;+2  9/14.../61
    asl
    asl
    asl
    asl             ;+8 17/22.../67

    sta HMP1            ;+3 20/25.../70
    sta RESP1           ;+3 23/28/33/38/43/48/53/58/63/68/73
    sta WSYNC           ;+3 0   begin line 2
    lda (MidSkyDataPtr),Y
    and MSOMask
    sta GRP0            ;+11    11
    dey             ;+2 13
    lda #$80
    sta HMP0            ;+5 18
    lda (MidSkyDataPtr),Y   ;+5 23
    and MSOMask         ;+3 26

    jsr Ret3
    jsr Ret3
    jsr Ret3                ;+36
    SLEEP 8             ;+8 70
    sta HMOVE
    sta WSYNC           ;+6 76
    sta GRP0            ;+3  3

    ldx Level           ;+3  6
    lda #0
    nop
    sta NUSIZ1          ;+3 13
    lda LowSkyObjectColorTable,X    ;+4 17  get color of LSO
    sta COLUP1          ;+3 20

    dey             ;+2 22
    SLEEP 5             ;+5 27
;---Fourth section of screen: 9 scanlines of tall & short scrolling bkgrnds (P0 & P1)
Screen4             ;
    jsr Ret3
    jsr Ret3            ;+24    51
    lda (Temp),Y
    sta.w PF0           ;+9 60
    lda (Temp+2),Y
    sta PF1         ;+8 68
    lda (Temp+4),Y
    sta PF2         ;+8 76
    lda (MidSkyDataPtr),Y
    and MSOMask
    sta GRP0            ;+11    11
    lda (LowSkyDataPtr),Y
    and LSOMask
    sta GRP1            ;+11    22
    dey
    bpl Screen4         ;+5 27
    jmp SwitchToBank1FromBank3

Ret3
    rts

;---------------------------------------------------------

MusicSubroutine
    dec TempoCounter
    bmi YesChangeToMusic
    jmp NoChangeToMusic

YesChangeToMusic
    lda GameFlags
    and #KERNELTYPE_BITS
    cmp #GAMEKERNEL
    beq GameKernelMusic
    lsr
    lsr
    lsr
    lsr
    lsr
    lsr
    clc
    adc #4
    tax
    .byte $2C
GameKernelMusic
    ldx Level
    lda TempoTable,X
    sta TempoCounter
    dec NoteLengthC0
    bpl Articulation
    lda SongPtr
    clc
    adc #2
    sta SongPtr
    lda SongPtr+1
    adc #0
    sta SongPtr+1
GetNote
    ldy #0
    lda (SongPtr),Y
    cmp #255
    bne SetMusicVariables
    iny
    lda (SongPtr),Y
    tax
    iny
    lda (SongPtr),Y
    sta SongPtr+1
    stx SongPtr
    jmp GetNote
SetMusicVariables
    ;--volume is set in articulation routine below
    lsr
    lsr
    lsr
    lsr
    sta NoteLengthC0
    iny
    lda (SongPtr),Y
    sta AUDF0
    lsr
    lsr
    lsr
    lsr
    lsr
    and #$03
    tax
    lda ToneTable,X
    sta AUDC0
Articulation
    ldy #1
    lda (SongPtr),Y
    bmi ArticulateNote
    ldx #16
    .byte $2C
ArticulateNote
    ldx NoteLengthC0
    dey
    lda (SongPtr),Y     ;get volume
    and #$0F
    sec
    sbc ArticulateTable,X
    bcs ApplyGlobalVolume
    lda #0
    sec
ApplyGlobalVolume
    sbc GlobalVolume
    bcs SetVolume
    lda #0
SetVolume
    bit SWCHB
    bpl MusicSwitchedOn
    lda #0
MusicSwitchedOn
    sta AUDV0
NoChangeToMusic

    lda GameFlags
    and #KERNELTYPE_BITS
    cmp #GAMEKERNEL
    bne NoSoundEffectsExceptDuringGameKernel
    jsr SoundEffectsSubroutine
    rts
NoSoundEffectsExceptDuringGameKernel
    lda #0
    sta AUDV1

    rts
;---------------------------------------------------------

ScoreBonusTen

    .byte 0,0,0,0,$50,$50,0,0,$00,$75,$75,$25,$25,$25,$75   ;floor items
    .byte 0,0,0,0,0,0,0,$00,0,$75,0,$25,$50,$00,$00     ;sky items



;---------------------------------------------------------

FindFloorPixel      ;X should be the band # (+1) upon entering this subroutine
            ;this should determine if there is floor underneath the player
            ;also used to determine if roof overhead.
            ;will change Temp through Temp+6 as well as A and X
            ;returns floor value in A

    lda PF0Data-1,X
    sta Temp
    lda PF1Data-1,X
    sta Temp+1
    lda PF2Data-1,X
    sta Temp+2
    lda PF3Data-1,X
    sta Temp+3
    lda PF4Data-1,X
    sta Temp+4
    lda PF5Data-1,X
    sta Temp+5

    lda ProtX
    sta Temp+6  ;save this for later.
    lsr
    lsr     ;divide by four, now A holds the left-most PF pixel the prot is over (0-39)
    tax


    ldy IndexIntoPFTable,X
    lda Temp,Y
    and SpecificPFPixelsTable,X
    bne IsFloor
    inx
    ldy IndexIntoPFTable,X
    lda Temp,Y
    and SpecificPFPixelsTable,X
    bne IsFloor

    lda SantaTemp       ;collision with PF stored here
    bmi OnlyCheckLeftPixelWhenNotHittingPF

    lda Temp+6  ;get saved value: ProtX-1
    and #%00000011  ;we want (ProtX-1) mod 4
                ;if that is > 0 then check three pixels, else check two
    bne CheckThree
OnlyCheckLeftPixelWhenNotHittingPF
    lda #0
    rts
CheckThree
    inx
    ldy IndexIntoPFTable,X
    lda Temp,Y
    and SpecificPFPixelsTable,X
    bne IsFloor
    rts
IsFloor
    lda #1
    rts



;---------------------------------------------------------


SoundEffectsTable	;unfilled because no sound effects made it in :(

SoundEffectsSubroutine
    ;--priority
    ;   1st: special sound effect
    ;   2nd: points accumulating
    ;   3rd: jumping or running

    lda SoundEffectsCounter
    beq NoSpecialSoundEffects
    ;--special sound effects
;    lda SoundEffectsType
;    asl
;    tax
;    lda SoundEffectsTable,X
;    sta Temp
;    lda SoundEffectsTable+1,X
;    sta Temp+1
;    lda SoundEffectsCounter
;    asl
;    tay         ;counter times two
;    lda (Temp),Y
;    sta AUDF1
;    iny
;    lda (Temp),Y
;    sta AUDV1
;    lsr
;    lsr
;    lsr
;    lsr
;    sta AUDC1
    rts

NoSpecialSoundEffects
    lda ScoreAdder
    bne PointsSoundEffect
    lda ScoreAdder+1
    beq NoPointsSoundEffect
PointsSoundEffect
    lda Counter
    and #3
    bne NoPointsSoundEffectThisFrame
    lda #SQUARESOUND
    sta AUDC1
    lda #6
    sta AUDF1
    lda #8
    .byte $2C
NoPointsSoundEffectThisFrame
    lda #3
    sta AUDV1
    rts

NoPointsSoundEffect
    lda GameFlags
    and #BETWEENLEVELS_BIT
    bne NoJumpOrRunSoundEffectBetweenLevels

    lda JumpIndex
    cmp #$FF
    beq NoJumpOrRunSoundEffect
    cmp #$FE
    beq RunSoundEffect
    ;--else jump effect.  Use JumpIndex as index into freq/volume table
    ldx JumpIndex
    lda JumpAUDC,X
    sta AUDC1
    lda JumpAUDF,X
    sta AUDF1
    lda #4
    sta AUDV1
    rts
RunSoundEffect
    ;--run sound effect.
    lda #RUNSOUND
    sta AUDC1
    lda #RUNFREQ
    sta AUDF1
    lda SantaAnimation
    and #$0F
    tax
    lda SantasSoundFrames,X
    beq NoJumpOrRunSoundEffect
    lda SantaAnimation
    lsr
    lsr
    lsr
    lsr
    tax
    lda SantasRunVolTable,X
    .byte $2C
NoJumpOrRunSoundEffectBetweenLevels
NoJumpOrRunSoundEffect
    lda #0
    sta AUDV1
    rts


    ;--DO NOT SEPARATE THE FOLLOWING TWO TABLES.  THEY SHARE VALUES!


;---------------------------------------------------------
;-------------------Music Data----------------------------
;---------------------------------------------------------

WeWishYou
    .byte QUARTER|V5,SOUND0|26

    .byte QUARTER|V7,ARTICULATE|SOUND0|19
    .byte EIGHTH|V7,SOUND0|19
    .byte EIGHTH|V8,SOUND0|17
    .byte EIGHTH|V8,SOUND0|19
    .byte EIGHTH|V7,SOUND0|20

    .byte QUARTER|V6,ARTICULATE|SOUND0|23
    .byte QUARTER|V6,ARTICULATE|SOUND0|23
    .byte QUARTER|V6,SOUND0|23

    .byte QUARTER|V7,ARTICULATE|SOUND0|17
    .byte EIGHTH|V7,SOUND0|17
    .byte EIGHTH|V8,SOUND0|15
    .byte EIGHTH|V8,SOUND0|17
    .byte EIGHTH|V7,SOUND0|19

    .byte QUARTER|V6,SOUND0|20
    .byte QUARTER|V6,ARTICULATE|SOUND0|26
    .byte QUARTER|V6,SOUND0|26

    .byte QUARTER|V9,ARTICULATE|SOUND0|15
    .byte EIGHTH|V8,SOUND0|15
    .byte EIGHTH|V9,SOUND0|14
    .byte EIGHTH|V9,SOUND0|15
    .byte EIGHTH|V8,SOUND0|17

    .byte QUARTER|V7,SOUND0|19
    .byte QUARTER|V6,SOUND0|23
    .byte EIGHTH|V6,ARTICULATE|SOUND0|26
    .byte EIGHTH|V6,SOUND0|26

    .byte QUARTER|V7,SOUND0|23
    .byte QUARTER|V8,SOUND0|17
    .byte QUARTER|V7,SOUND0|20

    .byte HALF|V8,SOUND0|19
    .byte 255
    .word WeWishYou


UpOnTheHouseTop
    .byte QUARTER|V4,ARTICULATE|SOUND0|16
    .byte LONG8TH|V4,SOUND0|16
    .byte SHORT8TH|V5,SOUND0|14
    .byte QUARTER|V5,ARTICULATE|SOUND0|16
    .byte LONG8TH|V4,SOUND0|19
    .byte SHORT8TH|V4,SOUND0|22

    .byte QUARTER|V5,SOUND0|25
    .byte QUARTER|V5,SOUND0|19
    .byte HALF|V6,SOUND0|16

    .byte QUARTER|V6,ARTICULATE|SOUND0|14
    .byte QUARTER|V6,SOUND0|14
    .byte QUARTER|V5,SOUND0|16
    .byte QUARTER|V5,SOUND0|19

    .byte QUARTER|V4,SOUND0|22
    .byte QUARTER|V5,ARTICULATE|SOUND0|16
    .byte HALF|V5,ARTICULATE|SOUND0|16

    .byte QUARTER|V4,ARTICULATE|SOUND0|16
    .byte LONG8TH|V4,SOUND0|16
    .byte SHORT8TH|V5,SOUND0|14
    .byte QUARTER|V5,ARTICULATE|SOUND0|16
    .byte LONG8TH|V4,SOUND0|19
    .byte SHORT8TH|V4,SOUND0|22

    .byte QUARTER|V5,SOUND0|25
    .byte QUARTER|V5,SOUND0|19
    .byte HALF|V6,SOUND0|16

    .byte QUARTER|V6,ARTICULATE|SOUND0|14
    .byte LONG8TH|V6,ARTICULATE|SOUND0|14
    .byte SHORT8TH|V6,SOUND0|14
    .byte LONG8TH|V5,ARTICULATE|SOUND0|16
    .byte SHORT8TH|V5,SOUND0|16
    .byte LONG8TH|V4,ARTICULATE|SOUND0|19
    .byte SHORT8TH|V4,SOUND0|19

    .byte QUARTER|V5,SOUND0|22
    .byte QUARTER|V7,SOUND0|16
    .byte HALF|V6,SOUND0|25

    .byte QUARTER|V5,ARTICULATE|SOUND0|18
    .byte QUARTER|V5,SOUND0|18
    .byte HALF|V6,SOUND0|14

    .byte QUARTER|V5,ARTICULATE|SOUND0|16
    .byte LONG8TH|V5,ARTICULATE|SOUND0|16
    .byte SHORT8TH|V5,SOUND0|16
    .byte HALF|V4,SOUND0|19

    .byte QUARTER|V4,SOUND0|22
    .byte QUARTER|V5,ARTICULATE|SOUND0|18
    .byte HALF|V6,SOUND0|18

    .byte QUARTER|V4,SOUND0|19
    .byte LONG8TH|V6,ARTICULATE|SOUND0|16
    .byte SHORT8TH|V6,SOUND0|16
    .byte QUARTER|V5,SOUND0|25
    .byte QUARTER|V6,SOUND0|19

    .byte QUARTER|V5,ARTICULATE|SOUND0|16
    .byte LONG8TH|V5,SOUND0|16
    .byte SHORT8TH|V5,SOUND0|14
    .byte QUARTER|V6,SOUND0|16
    .byte LONG8TH|V5,SOUND0|19
    .byte SHORT8TH|V5,SOUND0|22

    .byte QUARTER|V5,SOUND0|18
    .byte QUARTER|V5,SOUND0|16
    .byte HALF|V6,SOUND0|14

    .byte QUARTER|V6,ARTICULATE|SOUND0|16
    .byte LONG8TH|V6,SOUND0|16
    .byte SHORT8TH|V6,SOUND0|14
    .byte QUARTER|V5,SOUND0|16
    .byte LONG8TH|V5,ARTICULATE|SOUND0|19
    .byte SHORT8TH|V5,SOUND0|19

    .byte QUARTER|V5,SOUND0|22
    .byte QUARTER|V7,SOUND0|16
    .byte HALF|V6,SOUND0|25

    .byte 255
    .word UpOnTheHouseTop

GodRestYouMerryGentlemen
    .byte QUARTER|V7,ARTICULATE|SOUND1|31

    .byte QUARTER|V7,SOUND1|31
    .byte QUARTER|V8,ARTICULATE|SOUND1|20
    .byte QUARTER|V8,SOUND1|20
    .byte QUARTER|V7,SOUND1|23

    .byte QUARTER|V7,SOUND1|26
    .byte QUARTER|V7,SOUND1|28
    .byte QUARTER|V7,SOUND1|31
    .byte QUARTER|V8,SOUND2|6

    .byte QUARTER|V7,SOUND1|31
    .byte QUARTER|V7,SOUND1|28
    .byte QUARTER|V8,SOUND1|26
    .byte QUARTER|V8,SOUND1|23

    .byte HALF|V9,SOUND1|20
    .byte QUARTER|V9,SOUND1|20
    .byte QUARTER|V7,ARTICULATE|SOUND1|31

    .byte QUARTER|V7,SOUND1|31
    .byte QUARTER|V8,ARTICULATE|SOUND1|20
    .byte QUARTER|V8,SOUND1|20
    .byte QUARTER|V7,SOUND1|23

    .byte QUARTER|V7,SOUND1|26
    .byte QUARTER|V7,SOUND1|28
    .byte QUARTER|V7,SOUND1|31
    .byte QUARTER|V8,SOUND2|6

    .byte QUARTER|V7,SOUND1|31
    .byte QUARTER|V7,SOUND1|28
    .byte QUARTER|V8,SOUND1|26
    .byte QUARTER|V8,SOUND1|23

    .byte HALF|V9,SOUND1|20
    .byte QUARTER|V0,0
    .byte QUARTER|V7,SOUND1|20

    .byte QUARTER|V8,SOUND1|19
    .byte QUARTER|V7,SOUND1|23
    .byte QUARTER|V8,SOUND1|20
    .byte QUARTER|V8,SOUND1|19

    .byte QUARTER|V8,SOUND1|17
    .byte QUARTER|V9,SOUND1|15
    .byte QUARTER|V8,SOUND1|20
    .byte QUARTER|V8,SOUND1|23

    .byte QUARTER|V7,SOUND1|26
    .byte QUARTER|V7,SOUND1|31
    .byte QUARTER|V7,SOUND1|28
    .byte QUARTER|V7,SOUND1|26

    .byte HALF|V8,SOUND1|23
    .byte QUARTER|V9,SOUND1|26
    .byte QUARTER|V8,SOUND1|23

    .byte HALF|V8,SOUND1|20
    .byte QUARTER|V9,SOUND1|19
    .byte QUARTER|V8,ARTICULATE|SOUND1|20

    .byte QUARTER|V8,SOUND1|20
    .byte QUARTER|V8,SOUND1|23
    .byte QUARTER|V8,SOUND1|26
    .byte QUARTER|V8,SOUND1|28

    .byte HALF|V8,SOUND1|31
    .byte EIGHTH|V9,SOUND1|26
    .byte EIGHTH|V8,SOUND1|28
    .byte QUARTER|V7,SOUND1|31

    .byte HALF|V8,SOUND1|23
    .byte QUARTER|V9,SOUND1|26
    .byte QUARTER|V8,SOUND1|23

    .byte QUARTER|V8,SOUND1|20
    .byte QUARTER|V8,SOUND1|19
    .byte QUARTER|V8,SOUND1|17
    .byte QUARTER|V9,SOUND1|15

    .byte QUARTER|V8,SOUND1|20
    .byte QUARTER|V8,SOUND1|23
    .byte QUARTER|V8,SOUND1|26
    .byte QUARTER|V8,SOUND1|28

    .byte HALF|V8,SOUND1|31
    .byte QUARTER|V8,ARTICULATE|SOUND1|31


    .byte 255
    .word GodRestYouMerryGentlemen

JollyOldStNick
    .byte EIGHTH|V5,ARTICULATE|SOUND0|14
    .byte EIGHTH|V4,ARTICULATE|SOUND0|14
    .byte EIGHTH|V4,ARTICULATE|SOUND0|14
    .byte EIGHTH|V4,SOUND0|14

    .byte EIGHTH|V5,ARTICULATE|SOUND0|16
    .byte EIGHTH|V4,ARTICULATE|SOUND0|16
    .byte QUARTER|V4,SOUND0|16

    .byte EIGHTH|V5,ARTICULATE|SOUND0|18
    .byte EIGHTH|V4,ARTICULATE|SOUND0|18
    .byte EIGHTH|V4,ARTICULATE|SOUND0|18
    .byte EIGHTH|V4,SOUND0|18

    .byte HALF|V5,SOUND0|14

    .byte EIGHTH|V5,ARTICULATE|SOUND0|22
    .byte EIGHTH|V4,ARTICULATE|SOUND0|22
    .byte EIGHTH|V4,ARTICULATE|SOUND0|22
    .byte EIGHTH|V4,SOUND0|22

    .byte EIGHTH|V5,ARTICULATE|SOUND0|25
    .byte EIGHTH|V4,ARTICULATE|SOUND0|25
    .byte QUARTER|V5,SOUND0|18

    .byte EIGHTH|V5,SOUND0|19
    .byte EIGHTH|V4,SOUND0|18
    .byte EIGHTH|V5,SOUND0|16
    .byte EIGHTH|V4,SOUND0|14

    .byte HALF|V5,SOUND0|16

    .byte EIGHTH|V5,ARTICULATE|SOUND0|14
    .byte EIGHTH|V4,ARTICULATE|SOUND0|14
    .byte EIGHTH|V4,ARTICULATE|SOUND0|14
    .byte EIGHTH|V4,SOUND0|14

    .byte EIGHTH|V5,ARTICULATE|SOUND0|16
    .byte EIGHTH|V4,ARTICULATE|SOUND0|16
    .byte QUARTER|V5,SOUND0|16

    .byte EIGHTH|V5,ARTICULATE|SOUND0|18
    .byte EIGHTH|V4,ARTICULATE|SOUND0|18
    .byte EIGHTH|V4,ARTICULATE|SOUND0|18
    .byte EIGHTH|V4,SOUND0|18

    .byte HALF|V5,SOUND0|14

    .byte EIGHTH|V5,ARTICULATE|SOUND0|22
    .byte EIGHTH|V4,ARTICULATE|SOUND0|22
    .byte EIGHTH|V4,ARTICULATE|SOUND0|22
    .byte EIGHTH|V4,SOUND0|22

    .byte EIGHTH|V5,ARTICULATE|SOUND0|25
    .byte EIGHTH|V4,ARTICULATE|SOUND0|25
    .byte QUARTER|V5,SOUND0|18

    .byte EIGHTH|V5,SOUND0|16
    .byte EIGHTH|V4,SOUND0|18
    .byte EIGHTH|V5,SOUND0|16
    .byte EIGHTH|V4,SOUND0|14

    .byte HALF|V5,SOUND0|18

    .byte 255
    .word JollyOldStNick

GoodChristianMenRejoice
    .byte EIGHTH|V4,ARTICULATE|SOUND0|29

    .byte QUARTER|V5,ARTICULATE|SOUND0|29
    .byte EIGHTH|V3,SOUND0|29
    .byte QUARTER|V5,SOUND0|23
    .byte EIGHTH|V3,SOUND0|22

    .byte QUARTER|V5,SOUND0|19
    .byte EIGHTH|V4,SOUND0|17
    .byte QUARTER|V5,ARTICULATE|SOUND0|19
    .byte EIGHTH|V4,SOUND0|19

    .byte QUARTER|V5,ARTICULATE|SOUND0|29
    .byte EIGHTH|V3,SOUND0|29
    .byte QUARTER|V5,SOUND0|23
    .byte EIGHTH|V3,SOUND0|22

    .byte QUARTER|V5,SOUND0|19
    .byte EIGHTH|V4,SOUND0|17
    .byte QUARTER|V5,SOUND0|19
    .byte EIGHTH|V4,ARTICULATE|SOUND0|19

    .byte QUARTER|V5,SOUND0|19
    .byte EIGHTH|V4,SOUND0|17
    .byte QUARTER|V5,SOUND0|19
    .byte EIGHTH|V4,SOUND0|22

    .byte QUARTER|V5,SOUND0|23
    .byte EIGHTH|V3,SOUND0|26
    .byte QUARTER|V5,SOUND0|29
    .byte EIGHTH|V5,SOUND0|29

    .byte QUARTER|V5,ARTICULATE|SOUND0|26
    .byte EIGHTH|V3,SOUND0|26
    .byte QUARTER|V5,SOUND0|23
    .byte EIGHTH|V3,SOUND0|26

    .byte QUARTER|V5,SOUND0|29
    .byte EIGHTH|V3,SOUND0|26
    .byte QUARTER|V5,SOUND0|23
    .byte EIGHTH|V5,SOUND0|23

    .byte QUARTER|V5,SOUND0|19
    .byte EIGHTH|V4,SOUND0|17
    .byte QUARTER|V5,SOUND0|19
    .byte EIGHTH|V3,SOUND0|22

    .byte QUARTER|V5,SOUND0|23
    .byte EIGHTH|V3,SOUND0|26
    .byte QUARTER|V5,ARTICULATE|SOUND0|29
    .byte EIGHTH|V4,SOUND0|29

    .byte QUARTER|V5,ARTICULATE|SOUND0|26
    .byte EIGHTH|V3,SOUND0|26
    .byte QUARTER|V5,SOUND0|23
    .byte EIGHTH|V3,SOUND0|26

    .byte QUARTER|V5,SOUND0|29
    .byte EIGHTH|V3,SOUND0|26
    .byte QUARTER|V5,SOUND0|23
    .byte EIGHTH|V5,SOUND0|23

    .byte QUARTER|V5,ARTICULATE|SOUND1|11
    .byte EIGHTH|V3,SOUND1|11
    .byte QUARTER|V5,ARTICULATE|SOUND0|31
    .byte EIGHTH|V3,SOUND0|31

    .byte QUARTER|V5,SOUND0|29
    .byte EIGHTH|V5,SOUND0|29
    .byte QUARTER|V6,SOUND0|19
    .byte EIGHTH|V6,SOUND0|19

    .byte QUARTER|V5,ARTICULATE|SOUND0|23
    .byte EIGHTH|V3,SOUND0|23
    .byte QUARTER|V5,ARTICULATE|SOUND0|26
    .byte EIGHTH|V3,SOUND0|26

    .byte HALF|V5,SOUND0|29
    .byte EIGHTH|V5,ARTICULATE|SOUND0|29

    .byte 255
    .word GoodChristianMenRejoice
SilentNight
    .byte DOTTEDEIGHTH|V5,SOUND1|26
    .byte SIXTEENTH|V4,SOUND1|23
    .byte EIGHTH|V5,SOUND1|26
    .byte DOTTEDQUARTER|V4,SOUND1|31

    .byte DOTTEDEIGHTH|V5,SOUND1|26
    .byte SIXTEENTH|V4,SOUND1|23
    .byte EIGHTH|V5,SOUND1|26
    .byte DOTTEDQUARTER|V4,SOUND1|31

    .byte QUARTER|V6,ARTICULATE|SOUND1|17
    .byte EIGHTH|V6,SOUND1|17
    .byte DOTTEDQUARTER|V5,SOUND1|20

    .byte QUARTER|V5,ARTICULATE|SOUND1|19
    .byte EIGHTH|V5,SOUND1|19
    .byte DOTTEDQUARTER|V4,SOUND1|26

    .byte QUARTER|V4,ARTICULATE|SOUND1|23
    .byte EIGHTH|V4,SOUND1|23
    .byte DOTTEDEIGHTH|V5,SOUND1|19
    .byte SIXTEENTH|V4,SOUND1|20
    .byte EIGHTH|V5,SOUND1|23

    .byte DOTTEDEIGHTH|V5,SOUND1|26
    .byte SIXTEENTH|V4,SOUND1|23
    .byte EIGHTH|V5,SOUND1|26
    .byte DOTTEDQUARTER|V4,SOUND1|31

    .byte QUARTER|V4,ARTICULATE|SOUND1|23
    .byte EIGHTH|V4,SOUND1|23
    .byte DOTTEDEIGHTH|V5,SOUND1|19
    .byte SIXTEENTH|V4,SOUND1|20
    .byte EIGHTH|V5,SOUND1|23

    .byte DOTTEDEIGHTH|V5,SOUND1|26
    .byte SIXTEENTH|V4,SOUND1|23
    .byte EIGHTH|V5,SOUND1|26
    .byte DOTTEDQUARTER|V4,SOUND1|31

    .byte QUARTER|V5,ARTICULATE|SOUND1|17
    .byte EIGHTH|V5,SOUND1|17
    .byte DOTTEDEIGHTH|V6,SOUND1|14
    .byte SIXTEENTH|V4,SOUND1|17
    .byte EIGHTH|V5,SOUND1|20

    .byte DOTTEDQUARTER|V5,SOUND1|19
    .byte DOTTEDQUARTER|V6,SOUND1|15

    .byte EIGHTH|V5,SOUND1|19
    .byte EIGHTH|V5,SOUND1|26
    .byte EIGHTH|V5,SOUND1|31
    .byte DOTTEDEIGHTH|V5,SOUND1|26
    .byte SIXTEENTH|V4,SOUND1|14
    .byte EIGHTH|V5,SOUND1|17

    .byte DOTTEDQUARTER|V4,SOUND1|19
    .byte DOTTEDQUARTER|V4,SOUND1|19
    .byte 255
    .word SilentNightPreFunk


JingleBells
    .byte QUARTER|V0,0
    .byte EIGHTH|V6,SOUND1|11
    .byte EIGHTH|V8,SOUND0|20
    .byte EIGHTH|V8,SOUND0|23
    .byte EIGHTH|V7,SOUND0|26
    .byte DOTTEDQUARTER|V7,ARTICULATE|SOUND1|11
    .byte SIXTEENTH|V6,ARTICULATE|SOUND1|11
    .byte SIXTEENTH|V6,ARTICULATE|SOUND1|11

    .byte EIGHTH|V6,SOUND1|11
    .byte EIGHTH|V8,SOUND0|20
    .byte EIGHTH|V8,SOUND0|23
    .byte EIGHTH|V7,SOUND0|26
    .byte DOTTEDQUARTER|V7,ARTICULATE|SOUND0|31
    .byte EIGHTH|V7,ARTICULATE|SOUND0|31

    .byte EIGHTH|V6,SOUND0|31
    .byte EIGHTH|V8,SOUND0|19
    .byte EIGHTH|V8,SOUND0|20
    .byte EIGHTH|V7,SOUND0|23
    .byte DOTTEDQUARTER|V8,ARTICULATE|SOUND0|17
    .byte EIGHTH|V8,SOUND0|17

    .byte EIGHTH|V9,SOUND0|15
    .byte EIGHTH|V8,SOUND0|17
    .byte EIGHTH|V8,SOUND0|19
    .byte EIGHTH|V7,SOUND0|23
    .byte DOTTEDQUARTER|V8,SOUND0|20
    .byte EIGHTH|V6,ARTICULATE|SOUND1|11

    .byte EIGHTH|V6,SOUND1|11
    .byte EIGHTH|V8,SOUND0|20
    .byte EIGHTH|V8,SOUND0|23
    .byte EIGHTH|V7,SOUND0|26
    .byte DOTTEDQUARTER|V7,ARTICULATE|SOUND1|11
    .byte SIXTEENTH|V6,ARTICULATE|SOUND1|11
    .byte SIXTEENTH|V6,ARTICULATE|SOUND1|11

    .byte EIGHTH|V6,SOUND1|11
    .byte EIGHTH|V8,SOUND0|20
    .byte EIGHTH|V8,SOUND0|23
    .byte EIGHTH|V7,SOUND0|26
    .byte DOTTEDQUARTER|V7,ARTICULATE|SOUND0|31
    .byte EIGHTH|V7,ARTICULATE|SOUND0|31

    .byte EIGHTH|V7,SOUND0|31
    .byte EIGHTH|V8,SOUND0|19
    .byte EIGHTH|V8,SOUND0|20
    .byte EIGHTH|V7,SOUND0|23
    .byte EIGHTH|V8,ARTICULATE|SOUND0|17
    .byte EIGHTH|V8,ARTICULATE|SOUND0|17
    .byte EIGHTH|V8,ARTICULATE|SOUND0|17
    .byte EIGHTH|V8,SOUND0|17

    .byte EIGHTH|V9,SOUND0|15
    .byte EIGHTH|V8,SOUND0|17
    .byte EIGHTH|V8,SOUND0|19
    .byte EIGHTH|V7,SOUND0|23
    .byte HALF|V8,ARTICULATE|SOUND0|26

    ;--refrain:
    .byte EIGHTH|V8,ARTICULATE|SOUND0|20
    .byte EIGHTH|V7,ARTICULATE|SOUND0|20
    .byte QUARTER|V7,ARTICULATE|SOUND0|20
    .byte EIGHTH|V8,ARTICULATE|SOUND0|20
    .byte EIGHTH|V7,ARTICULATE|SOUND0|20
    .byte QUARTER|V7,ARTICULATE|SOUND0|20

    .byte EIGHTH|V7,SOUND0|20
    .byte EIGHTH|V9,SOUND0|17
    .byte DOTTEDEIGHTH|V8,SOUND0|26
    .byte SIXTEENTH|V7,SOUND0|23
    .byte HALF|V8,ARTICULATE|SOUND0|20

    .byte EIGHTH|V7,ARTICULATE|SOUND0|19
    .byte EIGHTH|V7,ARTICULATE|SOUND0|19
    .byte DOTTEDEIGHTH|V8,ARTICULATE|SOUND0|19
    .byte SIXTEENTH|V6,ARTICULATE|SOUND0|19
    .byte EIGHTH|V8,SOUND0|19
    .byte EIGHTH|V7,ARTICULATE|SOUND0|20
    .byte EIGHTH|V7,ARTICULATE|SOUND0|20
    .byte SIXTEENTH|V6,ARTICULATE|SOUND0|20
    .byte SIXTEENTH|V6,ARTICULATE|SOUND0|20

    .byte EIGHTH|V7,SOUND0|20
    .byte EIGHTH|V8,ARTICULATE|SOUND0|23
    .byte EIGHTH|V8,SOUND0|23
    .byte EIGHTH|V7,SOUND0|26
    .byte QUARTER|V8,SOUND0|23
    .byte QUARTER|V9,SOUND0|17

    .byte EIGHTH|V8,ARTICULATE|SOUND0|20
    .byte EIGHTH|V7,ARTICULATE|SOUND0|20
    .byte QUARTER|V7,ARTICULATE|SOUND0|20
    .byte EIGHTH|V8,ARTICULATE|SOUND0|20
    .byte EIGHTH|V7,ARTICULATE|SOUND0|20
    .byte QUARTER|V7,ARTICULATE|SOUND0|20

    .byte EIGHTH|V7,SOUND0|20
    .byte EIGHTH|V9,SOUND0|17
    .byte DOTTEDEIGHTH|V8,SOUND0|26
    .byte SIXTEENTH|V7,SOUND0|23
    .byte HALF|V8,ARTICULATE|SOUND0|20

    .byte EIGHTH|V7,ARTICULATE|SOUND0|19
    .byte EIGHTH|V7,ARTICULATE|SOUND0|19
    .byte DOTTEDEIGHTH|V8,ARTICULATE|SOUND0|19
    .byte SIXTEENTH|V6,ARTICULATE|SOUND0|19
    .byte EIGHTH|V8,SOUND0|19
    .byte EIGHTH|V7,ARTICULATE|SOUND0|20
    .byte EIGHTH|V7,ARTICULATE|SOUND0|20
    .byte SIXTEENTH|V6,ARTICULATE|SOUND0|20
    .byte SIXTEENTH|V7,ARTICULATE|SOUND0|20

    .byte EIGHTH|V9,ARTICULATE|SOUND0|17
    .byte EIGHTH|V8,SOUND0|17
    .byte EIGHTH|V7,SOUND0|19
    .byte EIGHTH|V7,SOUND0|23
    .byte DOTTEDQUARTER|V8,SOUND0|26
    .byte EIGHTH|V0,0
    .byte 255
    .word JingleBells



    align 256

Helicopter
        .byte #%00000000;--
        .byte #%00000000;--
        .byte #%00000000;--
        .byte #%00000000;--
        .byte #%00000000;--
        .byte #%00000000;--
        .byte #%00000000;--
        .byte #%00000000;--
        .byte #%00000000;--
        .byte #%00000000;--
        .byte #%00000000;--
        .byte #%00000000;--
        .byte #%00000000;--
        .byte #%00000000;--
        .byte #%00000000;--
        .byte #%00000000;--
        .byte #%00000000;--
        .byte #%11100000;--
        .byte #%11110000;--
        .byte #%01111100;--
        .byte #%00100010;--
        .byte #%11111000;--

Car
        .byte #%00010010;--
        .byte #%00111111;--
        .byte #%00111111;--
        .byte #%00010011;--
        .byte #%00001110;--
        .byte #%00000000;--
        .byte #%00000000;--
        .byte #%00000000;--
        .byte #%00000000;--
        .byte #%00000000;--
NewTrainShort
        .byte #%00100010;--
        .byte #%01011101;--
        .byte #%11111111;--
        .byte #%10000001;--
        .byte #%11111111;--
        .byte #%11111111;--
        .byte #%11010101;--
        .byte #%01111110;--
        .byte #%00000000;--
        .byte #%00000000;--

AtariTruckShort
        .byte #%00001010;--
        .byte #%00001010;--
        .byte #%11110101;--
        .byte #%11111111;--
        .byte #%01011111;--
        .byte #%10111111;--
        .byte #%10111111;--
        .byte #%10111111;--
        .byte #%10111111;--
        .byte #%11111111;--
Snowmobile
        .byte #%01100110;--
        .byte #%10001001;--
        .byte #%00101111;--
        .byte #%11110000;--
        .byte #%11111111;--
        .byte #%01110011;--
        .byte #%00101110;--
        .byte #%00000100;--
        .byte #%00001000;--
        .byte #%00001000;--
Skier
        .byte #%01111111;--
        .byte #%10000100;--
        .byte #%00001000;--
        .byte #%00011000;--
        .byte #%00001100;--
        .byte #%00000100;--
        .byte #%00111100;--
        .byte #%00001000;--
        .byte #%00010000;--
        .byte #%00010000;--

AtariFlag
        .byte #%10000000;--
        .byte #%10000000;--
        .byte #%10000000;--
        .byte #%10000000;--
        .byte #%10000000;--
        .byte #%10000011;--
        .byte #%10000111;--
        .byte #%11001101;--
        .byte #%11111101;--
        .byte #%11110101;--
        .byte #%11010011;--
        .byte #%11010011;--
        .byte #%11100011;--
        .byte #%11100011;--
        .byte #%11100111;--
        .byte #%11100111;--
        .byte #%11101100;--
        .byte #%11111000;--
        .byte #%00110000;--
        .byte #%00000000;--
        .byte #%10000000;--
        .byte #%00000000;--
WaterTower
        .byte #%10101010;--
        .byte #%11000110;--
        .byte #%11111110;--
        .byte #%11000110;--
        .byte #%10101010;--
        .byte #%10010010;--
        .byte #%10101010;--
        .byte #%11000110;--
        .byte #%01111100;--
        .byte #%01101100;--
        .byte #%01010100;--
        .byte #%01101100;--
        .byte #%00111000;--
        .byte #%00101000;--
        .byte #%01111100;--
        .byte #%01111100;--
        .byte #%01111100;--
        .byte #%01111100;--
        .byte #%11111110;--
        .byte #%01111100;--
        .byte #%00111000;--
        .byte #%00010000;--
Blimp
BlankShort
        .byte #%00000000;--
        .byte #%00000000;--
        .byte #%00000000;--
        .byte #%00000000;--
        .byte #%00000000;--
        .byte #%00000000;--
        .byte #%00000000;--
        .byte #%00000000;--
        .byte #%00000000;--
        .byte #%00000000;--
        .byte #%00000000;--
        .byte #%00000000;--
        .byte #%00000000;--
        .byte #%00000000;--
        .byte #%00000000;--
        .byte #%00010000;--
        .byte #%00111101;--
        .byte #%01111110;--
        .byte #%11111111;--
        .byte #%11111111;--
        .byte #%01111110;--
        .byte #%00111101;--
NewTrainTall
        .byte #%01001010;--
        .byte #%10110101;--
        .byte #%11111111;--
        .byte #%10000000;--
        .byte #%11111111;--
        .byte #%11111111;--
        .byte #%01010101;--
        .byte #%00111111;--
        .byte #%00000000;--
        .byte #%00000000;--
        .byte #%00000000;--
        .byte #%00000000;--
        .byte #%00000000;--
        .byte #%00000000;--
        .byte #%00000000;--
        .byte #%00000000;--
        .byte #%00000000;--
        .byte #%00000000;--
        .byte #%00000000;--
        .byte #%00000000;--
        .byte #%00000000;--
        .byte #%00000000;--
ImperialWalker
        .byte #%01011111;--
        .byte #%00101101;--
        .byte #%00101101;--
        .byte #%00101101;--
        .byte #%00101101;--
        .byte #%00011110;--
        .byte #%00010010;--
        .byte #%00010010;--
        .byte #%00010010;--
        .byte #%00010110;--
        .byte #%00011111;--
        .byte #%01011111;--
        .byte #%11111111;--
        .byte #%11111111;--
        .byte #%01011111;--
        .byte #%00001110;--
        .byte #%00001100;--
        .byte #%00000000;--
        .byte #%00000000;--
        .byte #%00000000;--
        .byte #%00000000;--
        .byte #%00000000;--
SatelliteDish
        .byte #%11000000;--
        .byte #%11000000;--
        .byte #%11000000;--
        .byte #%11000001;--
        .byte #%01100111;--
        .byte #%01101111;--
        .byte #%01011111;--
        .byte #%01011110;--
        .byte #%00111110;--
        .byte #%00111100;--
        .byte #%00111100;--
        .byte #%01111000;--
        .byte #%01111000;--
        .byte #%01110100;--
        .byte #%01110100;--
        .byte #%11100010;--
        .byte #%11100010;--
        .byte #%11000001;--
        .byte #%11000000;--
        .byte #%10000000;--
        .byte #%10000000;--
        .byte #%00000000;--


Horizon3PF2
        .byte #%11111111
        .byte #%11111111
        .byte #%11111100
        .byte #%00111100
        .byte #%00111100
        .byte #%00000000
        .byte #%00000000
        .byte #%00000000
        .byte #%00000000
        .byte #%00000000
Horizon3PF0
        .byte #%11110000
        .byte #%11110000
        .byte #%11110000
        .byte #%11110000
        .byte #%00110000
        .byte #%00110000
        .byte #%00110000
        .byte #%00110000
        .byte #%00110000
        .byte #%00110000
Horizon3PF1
        .byte #%11001111
        .byte #%11001111
        .byte #%11001111
        .byte #%11001111
        .byte #%11001111
        .byte #%11001111
        .byte #%11001110
        .byte #%00001110
        .byte #%00001110
        .byte #%00001110

PolarBear
        .byte #%01101100;--
        .byte #%01001000;--
        .byte #%01101000;--
        .byte #%01111000;--
        .byte #%11111011;--
        .byte #%11111111;--
        .byte #%11111110;--
        .byte #%11111100;--
        .byte #%11111000;--
        .byte #%01100000;--
OldTrainShort
        .byte #%00100010;--
        .byte #%00100010;--
        .byte #%00011100;--
        .byte #%11111111;--
        .byte #%01111111;--
        .byte #%00110110;--
        .byte #%00110110;--
        .byte #%01111111;--
        .byte #%00111110;--
        .byte #%10001000;--

    align 256

CellPhoneTower
        .byte #%00011000;--
        .byte #%00011000;--
        .byte #%00011000;--
        .byte #%00011000;--
        .byte #%00011000;--
        .byte #%00011000;--
        .byte #%00011000;--
        .byte #%00011000;--
        .byte #%00010000;--
        .byte #%00011100;--
        .byte #%10011101;--
        .byte #%10111101;--
        .byte #%10111101;--
        .byte #%10011101;--
        .byte #%11111111;--
        .byte #%10111101;--
        .byte #%10111101;--
        .byte #%10011101;--
        .byte #%00011100;--
        .byte #%00010000;--
        .byte #%00011000;--
        .byte #%00011000;--
    ;--DO NOT SEPARATE THE FOLLOWING TWO TABLES - THEY SHARE VALUES!
AtariTruckTall
        .byte #%01001010;--
        .byte #%01001010;--
        .byte #%10110101;--
        .byte #%11111111;--
        .byte #%11110001;--
        .byte #%11110111;--
        .byte #%01110111;--
        .byte #%00010111;--
        .byte #%00110111;--
        .byte #%00011111;--
        .byte #%00001000;--
        .byte #%00001000;--
        .byte #%00001000;--
        .byte #%00001000;--
        .byte #%00000000;--
        .byte #%00000110;--
        .byte #%00000011;--
        .byte #%00000000;--
        .byte #%00000000;--
Speeder
        .byte #%00000000;--
        .byte #%00000000;--
        .byte #%00000000;--
        .byte #%00000010;--
        .byte #%00001111;--
        .byte #%00000110;--
        .byte #%00000000;--
        .byte #%00000000;--
        .byte #%00000000;--
        .byte #%00000000;--

ASnowman                ;horizon abominable snowman
        .byte #%01110011;--
        .byte #%01110001;--
        .byte #%00010111;--
        .byte #%00010111;--
        .byte #%00010100;--
        .byte #%00010100;--
        .byte #%00010100;--
        .byte #%00011100;--
        .byte #%00011100;--
        .byte #%00001110;--
        .byte #%00001110;--
        .byte #%00001110;--
        .byte #%01001110;--
        .byte #%01101110;--
        .byte #%10111110;--
        .byte #%11011110;--
        .byte #%01111110;--
        .byte #%00001110;--
        .byte #%00011100;--
        .byte #%00011100;--
        .byte #%00011100;--
        .byte #%00001100;--
DogsledShort
        .byte #%00111111;--
        .byte #%01011010;--
        .byte #%01011010;--
        .byte #%01000010;--
        .byte #%00100010;--
        .byte #%00000110;--
        .byte #%00000010;--
        .byte #%00000000;--
        .byte #%00000010;--
        .byte #%00000010;--
Horizon0PF0
    .byte %11110000
    .byte %11110000
    .byte %01100000
    .byte %00000000
    .byte %00000000
    .byte %00000000
    .byte %00000000
    .byte %00000000
    .byte %00000000
    .byte %00000000
Horizon0PF1
    .byte %11111111
    .byte %11111111
    .byte %11111111
    .byte %01111111
    .byte %00111110
    .byte %00011000
    .byte %00000000
    .byte %00000000
    .byte %00000000
    .byte %00000000
Horizon0PF2
    .byte %11111111
    .byte %11111011
    .byte %01110001
    .byte %00100000
    .byte %00000000
    .byte %00000000
    .byte %00000000
    .byte %00000000
    .byte %00000000
    .byte %00000000



Horizon1PF0
    .byte %11110000
    .byte %11110000
    .byte %11110000
    .byte %11100000
    .byte %11000000
    .byte %10000000
    .byte %00000000
    .byte %00000000
    .byte %00000000
    .byte %00000000
Horizon1PF1
    .byte %11111111
    .byte %11111111
    .byte %11111111
    .byte %11111111
    .byte %11011111
    .byte %10001111
    .byte %00001111
    .byte %00000111
    .byte %00000011
    .byte %00000000
Horizon1PF2
    .byte %11111111
    .byte %11111111
    .byte %11111111
    .byte %11111111
    .byte %01111111
    .byte %00111111
    .byte %00011111
    .byte %00001101
    .byte %00000000
    .byte %00000000



Horizon2PF0
    .byte %11110000
    .byte %11110000
    .byte %11110000
    .byte %11100000
    .byte %11100000
    .byte %11000000
    .byte %11000000
    .byte %10000000
    .byte %00000000
    .byte %00000000

Horizon2PF1
    .byte %11111111
    .byte %11111110
    .byte %11111000
    .byte %11110000
    .byte %11100000
    .byte %11000000
    .byte %10000000
    .byte %00000000
    .byte %00000000
    .byte %00000000

Horizon2PF2
    .byte %11111111
    .byte %11111111
    .byte %00111110
    .byte %00011110
    .byte %00001100
    .byte %00000100
    .byte %00000000
    .byte %00000000
    .byte %00000000
    .byte %00000000
USFlag
        .byte #%10000000;--
        .byte #%10000000;--
        .byte #%10000000;--
        .byte #%10000000;--
        .byte #%10000000;--
        .byte #%10000000;--
        .byte #%10000011;--
        .byte #%10000100;--
        .byte #%11001011;--
        .byte #%10110100;--
        .byte #%11001011;--
        .byte #%10110100;--
        .byte #%11001011;--
        .byte #%10110100;--
        .byte #%10001011;--
        .byte #%10000100;--
        .byte #%10001011;--
        .byte #%10000100;--
        .byte #%11001000;--
        .byte #%00110000;--
        .byte #%00000000;--
        .byte #%10000000;--
DogsledTall
        .byte #%00100100;--
        .byte #%00100100;--
        .byte #%01111101;--
        .byte #%11111110;--
        .byte #%11111100;--
        .byte #%01000000;--
        .byte #%00000000;--
        .byte #%00000000;--
        .byte #%00000000;--
        .byte #%00000000;--
        .byte #%00000000;--
        .byte #%00000000;--
        .byte #%00000000;--
        .byte #%00000000;--
        .byte #%00000000;--
        .byte #%00000000;--
        .byte #%00000000;--
        .byte #%00000000;--
        .byte #%00000000;--
        .byte #%00000000;--
        .byte #%00000000;--
    ;--The tables above and below share a value.
Sun
        .byte #%00000000;--
        .byte #%00111000
        .byte #%01111100
        .byte #%11111110
        .byte #%11111110
        .byte #%11111110
        .byte #%11111110
        .byte #%01111100
        .byte #%00111000
SchoolBusShort
        .byte #%01000000;--
        .byte #%01000000;--
        .byte #%10110000;--
        .byte #%11110000;--
        .byte #%11110000;--
        .byte #%11110000;--
        .byte #%01010000;--
        .byte #%01010000;--
        .byte #%11110000;--
        .byte #%11110000;--
TankerShort
        .byte #%00001010;--
        .byte #%00001010;--
        .byte #%00010101;--
        .byte #%11111111;--
        .byte #%11111111;--
        .byte #%11111111;--
        .byte #%11111111;--
        .byte #%11111111;--
        .byte #%11111111;--
        .byte #%00001000;--

Superman
        .byte #%00000001;--
        .byte #%00000001;--
        .byte #%00000011;--
        .byte #%00000111;--
        .byte #%01101110;--
        .byte #%11111100;--
        .byte #%00111000;--
        .byte #%01110000;--
        .byte #%01101100;--
        .byte #%01100011;--


    align 256

    ;--DO NOT SEPARATE THE FOLLOWING TWO TABLES - THEY SHARE VALUES!
SchoolBusTall
        .byte #%01000000;--
        .byte #%01000000;--
        .byte #%10111111;--
        .byte #%11111111;--
        .byte #%11111111;--
        .byte #%11111111;--
        .byte #%11010101;--
        .byte #%01010101;--
        .byte #%00111111;--
        .byte #%00111111;--
Airplane
        .byte #%00000000;--
        .byte #%00000000;--
        .byte #%00000000;--
        .byte #%00000000;--
        .byte #%00000000;--
        .byte #%00000000;--
        .byte #%00000000;--
        .byte #%00000000;--
        .byte #%00000000;--
        .byte #%00000000;--
        .byte #%00000000;--
        .byte #%00000000;--
        .byte #%00000000;--
        .byte #%00000000;--
        .byte #%00000000;--
        .byte #%00001000;--
        .byte #%00110000;--
        .byte #%11111100;--
        .byte #%11111110;--
        .byte #%01111111;--
        .byte #%00000001;--
        .byte #%00000001;--
;---Crescent Moon Data



Snowman
        .byte #%00111000;--
        .byte #%01111100;--
        .byte #%11111110;--
        .byte #%11101110;--
        .byte #%11111110;--
        .byte #%11101110;--
        .byte #%11111110;--
        .byte #%01101100;--
        .byte #%00111000;--
        .byte #%01101100;--
        .byte #%01010111;--
        .byte #%01111101;--
        .byte #%01010100;--
        .byte #%00111000;--
        .byte #%01111100;--
        .byte #%00111000;--
        .byte #%00111000;--
        .byte #%00111000;--
        .byte #%00111000;--
        .byte #%00000000;--
        .byte #%00000000;--
    ;--The tables above and below share a value.
Moon
        .byte #%00000000;--
        .byte #%00011000;--
        .byte #%00111100;--
        .byte #%01110010;--
        .byte #%01100000;--
        .byte #%01100000;--
        .byte #%01100000;--
        .byte #%00110000;--
        .byte #%00011000;--

PolarBearTall
        .byte #%00010110;--
        .byte #%00001010;--
        .byte #%00001010;--
        .byte #%00011110;--
        .byte #%00011100;--
        .byte #%00011011;--
        .byte #%00011011;--
        .byte #%00011010;--
        .byte #%00011010;--
        .byte #%00001110;--
        .byte #%00001110;--
        .byte #%00000110;--
        .byte #%00000110;--
        .byte #%00000110;--
        .byte #%00011110;--
        .byte #%00011110;--
        .byte #%00011100;--
        .byte #%00001100;--
        .byte #%00000000;--
        .byte #%00000000;--
        .byte #%00000000;--
        .byte #%00000000;--

NorthPole
        .byte #%11111111;--
        .byte #%00111100;--
        .byte #%00010000;--
        .byte #%00000000;--
        .byte #%00000000;--
        .byte #%00001000;--
        .byte #%00011000;--
        .byte #%00010000;--
        .byte #%00000000;--
        .byte #%00000000;--
        .byte #%00001000;--
        .byte #%00011000;--
        .byte #%00010000;--
        .byte #%00000000;--
        .byte #%00000000;--
        .byte #%00001000;--
        .byte #%00011000;--
        .byte #%00111100;--
        .byte #%00000000;--
        .byte #%00011000;--
        .byte #%00011000;--
        .byte #%00011000;--

Minivan
        .byte #%01000100;--
        .byte #%01000100;--
        .byte #%10111010;--
        .byte #%11111110;--
        .byte #%11111110;--
        .byte #%11111110;--
        .byte #%10000010;--
        .byte #%01000010;--
        .byte #%00111110;--
        .byte #%00000000;--
        .byte #%00000000;--
        .byte #%00000000;--
        .byte #%00000000;--
        .byte #%00000000;--
        .byte #%00000000;--
        .byte #%00000000;--
        .byte #%00000000;--
        .byte #%00000000;--
        .byte #%00000000;--
        .byte #%00000000;--
        .byte #%00000000;--
        .byte #%00000000;--
OldTrainTall
        .byte #%00100010;--
        .byte #%00100111;--
        .byte #%11011111;--
        .byte #%01111111;--
        .byte #%01111010;--
        .byte #%11111101;--
        .byte #%11111111;--
        .byte #%01111101;--
        .byte #%01010101;--
        .byte #%01000101;--
        .byte #%01001111;--
        .byte #%01000000;--
        .byte #%01000000;--
        .byte #%00000000;--
        .byte #%00000000;--
        .byte #%01000000;--
        .byte #%01000000;--
        .byte #%00100000;--
        .byte #%00001100;--
        .byte #%00011110;--
        .byte #%00001110;--
        .byte #%00000100;--

TankerTall
        .byte #%01001010;--
        .byte #%01001010;--
        .byte #%10110100;--
        .byte #%11111110;--
        .byte #%11100000;--
        .byte #%11101111;--
        .byte #%11101111;--
        .byte #%00101111;--
        .byte #%01101111;--
        .byte #%00010001;--
        .byte #%00010000;--
        .byte #%00010000;--
        .byte #%00010000;--
        .byte #%00010000;--
        .byte #%00000000;--
        .byte #%00001110;--
        .byte #%00000011;--
        .byte #%00000000;--
        .byte #%00000000;--
        .byte #%00000000;--
        .byte #%00000000;--
        .byte #%00000000;--
MonsterTruckTall
        .byte #%01000010;--
        .byte #%11100111;--
        .byte #%10100101;--
        .byte #%11100111;--
        .byte #%01011010;--
        .byte #%00100100;--
        .byte #%01011010;--
        .byte #%10011001;--
        .byte #%11111111;--
        .byte #%11111111;--
        .byte #%11110101;--
        .byte #%01010110;--
        .byte #%00110100;--
        .byte #%00001000;--
        .byte #%00000000;--
    ;---the tables above and below share 7 values
MonsterTruckShort
    .byte 0,0,0,0,0,0,0,128,128,128
PickupTall
        .byte #%01000100;--
        .byte #%01000100;--
        .byte #%10111010;--
        .byte #%11111111;--
        .byte #%11111110;--
        .byte #%11110000;--
        .byte #%01010000;--
        .byte #%00110000;--
        .byte #%00000000;--
        .byte #%00000000;--
        .byte #%00000000;--
        .byte #%00000000;--
        .byte #%00000000;--
        .byte #%00000000;--
        .byte #%00000000;--
        .byte #%00000000;--
        .byte #%00000000;--
        .byte #%00000000;--
        .byte #%00000000;--
        .byte #%00000000;--
        .byte #%00000000;--
        .byte #%00000000;--
PickupShort
        .byte #%00100000;--
        .byte #%00100000;--
        .byte #%11011000;--
        .byte #%11111000;--
        .byte #%11111000;--
        .byte #%00000000;--
        .byte #%11111000;--
        .byte #%00000000;--
        .byte #%00000000;--
        .byte #%00000000;--
MinivanCar
        .byte #%00010010;--
        .byte #%00010010;--
        .byte #%00101101;--
        .byte #%00111111;--
        .byte #%00111111;--
        .byte #%00010010;--
        .byte #%00001110;--
        .byte #%00000000;--
        .byte #%00000000;--
        .byte #%00000000;--
  IF TV_MODE = NTSC
HighSkyObjectColorTable
    .byte GOLD+14,GRAY+10,GRAY+12,GRAY+14
SkyColorTable
    .byte BLUE2+14,BLUE2+4,BLUE2+0,GRAY+0
MidSkyObjectColorTable
    .byte GRAY+14,GRAY+4,GRAY+6,GRAY+2
LowSkyObjectColorTable
    .byte GRAY+14,GRAY+4,GRAY+6,LIGHTBLUE+2
  ELSE
HighSkyObjectColorTable
    .byte GOLD+14,GRAY+12,GRAY+12,GRAY+12
SkyColorTable
    .byte BLUE2+10,BLUE2+2,BLUE2+0,GRAY+0
MidSkyObjectColorTable
    .byte GRAY+14,GRAY+6,GRAY+8,GRAY+4
LowSkyObjectColorTable
    .byte GRAY+14,GRAY+6,GRAY+8,GRAY+4
  ENDIF
JumpTable
    .byte 0,-1,0,-1,0,0,0,0
    .byte 0,0,1,0,0,1,0,1
    .byte 1,0,1,1,1,2,1,2
    .byte 2,1,2,2,2,2,2,2       ;regular jump starts here (31)
    .byte 3,3,3,4,4,4,4,4
    .byte 4,4,4,4,4,4,4,4
SkyItemJumpTable
    .word 0,EvilBirdCollisionRoutine,ReindeerCollisionRoutine,SnowFlurryCollisionRoutine
    .word ToxicCloudCollisionRoutine,ReindeerCollisionRoutine,ReindeerCollisionRoutine
    .word LightningCollisionRoutine,FlyingHatCollisionRoutine,SnowspeederCollisionRoutine
    .word ListCollisionRoutine,TornadoCollisionRoutine,ElfCollisionRoutine,SnowflakeCollisionRoutine
    .word SleighCollisionRoutine,SleighCollisionRoutine

ForcedActionTable
    .byte 1,1,1,2,2,2,2,2
    .byte 3,3,3,3,3,3,3,3
    .byte 3,3,3,3,3,3,3,3
    .byte 3,3,3,3,3,3,3,3
    .byte 3,3,3,3,3,3,3,3
    .byte 3,3,3,3,3,3,3,3



FloorItemJumpTable
    .word 0,CompressedSpringCollisionRoutine,ExpandedSpringCollisionRoutine
    .word RightArrowCollisionRoutine,LeftArrowCollisionRoutine,GiftCollisionRoutine,CookiesCollisionRoutine
    .word LurkingSnowmanCollisionRoutine,LungingSnowmanCollisionRoutine,ToysackCollisionRoutine
    .word CandleCollisionRoutine,CandyCaneCollisionRoutine,CoalCollisionRoutine,BellCollisionRoutine
    .word CocoaCollisionRoutine,MilkCollisionRoutine

ReindeerBonusTable
    .word $1125,$2250,$4500,$9000

CumulativeBandHeightTable
    .byte 60,55,45,33,29,25,21,9


IndexIntoPFTable
    .byte 0,0,0,0
    .byte 1,1,1,1,1,1,1,1
    .byte 2,2,2,2,2,2,2,2
    .byte 3,3,3,3
    .byte 4,4,4,4,4,4,4,4
    .byte 5,5,5,5,5,5,5,5
SpecificPFPixelsTable
    .byte $10,$20,$40,$80
    .byte $80,$40,$20,$10,$08,$04,$02,$01
    .byte $01,$02,$04,$08,$10,$20,$40,$80
    .byte $10,$20,$40,$80
    .byte $80,$40,$20,$10,$08,$04,$02,$01
    .byte $01,$02,$04,$08,$10,$20,$40,$80

BandHeightData  ;used in overscan to check if player is standing on something (10 bytes)
    .byte #BAND0HEIGHT,#BAND1HEIGHT,#BAND2HEIGHT,#BAND3HEIGHT,#BAND4HEIGHT,#BAND5HEIGHT,#BAND6HEIGHT,#BAND7HEIGHT

HeadClearanceTable
    .byte -1,0

SantasSoundFrames
    .byte 8,0
SantasRunVolTable
    .byte 0,0,0,8,0,0,0,0,0

JumpAUDC
    .byte SQUARESOUND,SQUARESOUND,SQUARESOUND,SQUARESOUND
    .byte SQUARESOUND,SQUARESOUND,SQUARESOUND,SQUARESOUND

    .byte SQUARESOUND,SQUARESOUND,SQUARESOUND,SQUARESOUND
    .byte SQUARESOUND,SQUARESOUND,SQUARESOUND,SQUARESOUND
    .byte SQUARESOUND,SQUARESOUND,SQUARESOUND,SQUARESOUND
    .byte SQUARESOUND,SQUARESOUND,SQUARESOUND,SQUARESOUND
    .byte SQUARESOUND,SQUARESOUND,SQUARESOUND,SQUARESOUND
    .byte LEADSOUND,LEADSOUND,LEADSOUND,LEADSOUND
    .byte LEADSOUND,LEADSOUND,LEADSOUND,LEADSOUND
    .byte LEADSOUND,LEADSOUND,LEADSOUND,LEADSOUND
    .byte LEADSOUND,LEADSOUND
    .byte LEADSOUND,LEADSOUND,LEADSOUND,LEADSOUND
    .byte LEADSOUND,LEADSOUND

NoMusic
    .byte HALF|V0,0
    .byte 255
    .word NoMusic

ToneTable
    .byte TONE0,TONE1,TONE2,TONE3


ArticulateTable
    .byte 10,0,1,0,1,0,1,0
    .byte 0,1,0,0,0,0,0,0
    .byte 0

TempoTable
    .byte TEMPO225,TEMPO225,TEMPO225,TEMPO225,TITLESCREENTEMPO,GAMEOVERTEMPO,FINALSCREENTEMPO

	;THE FOLLOWING TWO TABLES SHARE 8 BYTES!  DO NOT SEPARATE!
EnergyBonus
    .byte 0,0,0,0,0,$80,0,0,0,0,$20,0,0,$60,$40     ;floor items
    .byte 0,0,0,0,0,0,0         ;sky items
JumpAUDF
    .byte 0,0,0,0,0,0,0,0
    .byte 12,13,14,15
    .byte 16,17,18,19,20,21,22,23
    .byte 24,25,26,27,28,29,30,31
    .byte 10,11,12,13,14,15,16,17
    .byte 18,19,20,21,22,23,24,25
    .byte 26,27,28,29,30,31

GlobalVolumeTable
    .byte 11,11,10,10,9,9,8,8
    .byte 7,7,6,6,5,5,4,4,3,3
    .byte 2,2,1,1,0,0,0



;COMPRESSEDSPRING   =   $01
;EXPANDEDSPRING     =   $02
;RIGHTARROW     =   $03
;LEFTARROW      =   $04
;GIFT           =   $05
;COOKIES        =   $06
;LURKINGSNOWMAN     =   $07
;LUNGINGSNOWMAN     =   $08
;TOYSACK        =   $09
;ORNAMENT       =   $0A
;CANDYCANE      =   $0B
;COAL           =   $0C
;BELL           =   $0D
;COCOA          =   $0E
;MILK           =   $0F

;EVILBIRD       =   $10
;REINDEER1      =   $20
;SNOWFLURRY     =   $30
;METHANE        =   $40
;REINDEER2      =   $50
;REINDEER3      =   $60
;LIGHTNING      =   $70
;FLYINGHAT      =   $80
;SNOWSPEEDER        =   $90
;LIST           =   $A0
;TORNADO        =   $B0
;ELF            =   $C0
;SNOWFLAKE      =   $D0
;SLEIGH1        =   $E0
;SLEIGH2        =   $F0

    ;note: reindeer bonuses are elsewheres


;---------------------------------------------------------
;---------------------------------------------------------
;---------------------------------------------------------




SilentNightPreFunk
    .byte HALF|V0,0



    org $3FC8
    rorg $FFC8
    jmp HorizonKernelSubroutine
	.byte 0,0,0
ReadConsoleSwitchesInBank2
	sta $1FF7
    org $3FDA
    rorg $FFDA
    .byte 0,0,0     ;A,B,C
	rts
    .byte 0,0	;,0     ;D,E,F
    .byte 0,0,0     ;E0,1,2
    jmp Overscan        ;3,4,5
StartNewLevelFromBank3
    sta $1FF7       ;6,7,8
    .byte 0,0,0     ;9,A,B
    jmp MusicSubroutine ;C,D,E
SwitchToBank1FromBank3
    sta $1FF6       ;F,F0,1


    org $3FFC
    rorg $FFFC

    .word Start3
    .word Start3